@@ -1,7 +1,7 @@
 /*
  * Functions for watching file descriptors in other processes.
  *
- * Copyright 2002-2008, 2010, 2012-2015, 2017, 2021, 2023-2024 Andrew Wood
+ * Copyright 2002-2008, 2010, 2012-2015, 2017, 2021, 2023-2025 Andrew Wood
  *
  * License GPLv3+: GNU GPL version 3 or later; see `docs/COPYING'.
  */
@@ -490,6 +490,7 @@ int pv_watchpid_scanfds(pvstate_t state,
 		info_array[use_idx].state->control.name = NULL;
 		info_array[use_idx].state->control.format_string = NULL;
 		info_array[use_idx].state->control.output_name = NULL;
+		info_array[use_idx].state->control.default_bar_style = NULL;
 		/*@+mustfreeonly@ */
 		info_array[use_idx].state->control.default_format[0] = '\0';
 		use_format_string =
@@ -498,6 +499,13 @@ int pv_watchpid_scanfds(pvstate_t state,
 			(void) pv_snprintf(info_array[use_idx].state->control.default_format, PV_SIZEOF_DEFAULT_FORMAT,
 					   "%.510s", use_format_string);
 
+		/*
+		 * Duplicate the default bar style string, if there is one.
+		 */
+		if (NULL != state->control.default_bar_style) {
+			pv_state_default_bar_style_set(info_array[use_idx].state, state->control.default_bar_style);
+		}
+
 		/*
 		 * Copy over all the display values, blanking out the
 		 * dynamically allocated parts as above; then set the
